pub struct ListTableMetadataPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListTableMetadataPaginator
This is created with .items()
Implementations
Sourceimpl ListTableMetadataPaginatorItems
impl ListTableMetadataPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<TableMetadata, SdkError<ListTableMetadataError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<TableMetadata, SdkError<ListTableMetadataError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().